# Python ImageManipulating

Python ImageManipulating is a Python library for python developers to ease dealing with images and manipulating them.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install discord.py-images.

```bash
pip install python-imagemanipulating
```

## Usage

```python
soon
```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)